@@ -148,6 +148,14 @@ sim <- function (ode = NULL,
   if(!is.null(lagtime)) {
     regimen <- apply_lagtime(regimen, lagtime, parameters, attr(ode, "cmt_mapping"))
   }
+  if(!is.null(attr(ode, "dose")$duration_scale)) {
+    regimen <- apply_duration_scale(
+      regimen,
+      attr(ode, "dose")$duration_scale,
+      parameters,
+      attr(ode, "cmt_mapping")
+    )
+  }
   if(t_init != 0) regimen$dose_times <- regimen$dose_times + t_init
   p <- as.list(parameters)
   if(!is.null(t_obs)) {
@@ -181,6 +189,11 @@ sim <- function (ode = NULL,
         p <- parameters
       }
     }
+    if(!is.null(attr(ode, "iov")$n_bins) && attr(ode, "iov")$n_bins > 1) {
+      if(attr(ode, "iov")$n_bins != (length(iov_bins)-1)) {
+        warning("Number of IOV bins specified for model does not match supplied `iov_bins` argument. This could lead to simulation failures or erroneous output.")
+      }
+    }
     if(is.null(analytical)) {
       if(inherits(ode, "function") && !isTRUE(attr(ode, "cpp"))) {
         stop("Sorry. Non-C++ functions are deprecated as input for ODE.")
